@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hpack
-version: 0.12.0
-id: hpack-0.12.0-6b445c3e78c86c98ec404c4d62d20a19
-key: hpack_JV9tdDvDrJkEWveYEfzzIf
+version: 0.14.0
+id: hpack-0.14.0-4cc191cba2ea62556a2664ee9d3e0a8c
+key: hpack_JkFq4rajcTIEQO5Dac6EQt
 license: MIT
 maintainer: Simon Hengel <sol@typeful.net>
 homepage: https://github.com/sol/hpack#readme
@@ -15,13 +15,13 @@ exposed-modules:
 hidden-modules: Hpack.FormattingHints Hpack.GenericsUtil
                 Hpack.Haskell Hpack.Render Hpack.Util Paths_hpack
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/hpack-0.12.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/hpack-0.12.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/hpack-0.12.0
-hs-libraries: HShpack-0.12.0-JV9tdDvDrJkEWveYEfzzIf
+import-dirs: /usr/lib/ghc-7.10.3/site-local/hpack-0.14.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/hpack-0.14.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/hpack-0.14.0
+hs-libraries: HShpack-0.14.0-JkFq4rajcTIEQO5Dac6EQt
 depends:
     Glob-0.7.5-2de4d761061e270a9c358a45d1e533d4
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-compat-0.9.1-b27a2a11ed624cad5ac469eab39183ee
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
@@ -30,7 +30,7 @@ depends:
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    yaml-0.8.17-256008eb42bc8c59588e1e26ecb14272
+    yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
 haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
 haddock-html: /usr/share/doc/haskell-hpack/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
